@@ -258,7 +258,7 @@ class Get_ASM_Consume:
             if float(today_credits_num) != yes_credits_num:
                 yes_run_num = round(yes_credits_num - today_credits_num, 2)  # 昨日消耗的；
                 # now_yue_num = budget_amount - spent_value  # 限制消耗金额减去当前总消耗
-                now_yue_days = int(math.floor(float(today_credits_num) / yes_run_num))  # 预估还可消耗天数；
+                now_yue_days = math.floor(float(today_credits_num) / yes_run_num)  # 预估还可消耗天数；
             else:
                 # 如果今日昨日一样，代表没消耗的，就可以跳过；
                 yes_run_num = '空'
@@ -266,7 +266,7 @@ class Get_ASM_Consume:
             # 加入推送列表；
             push_title = '七麦科技-ASM账户总可用信用额度监控'
             asm_link = 'https://app.searchads.apple.com/cm/app/settings/billing/loc'
-            push_text = "### %s-七麦科技-ASM信用额度提醒 \n\n**今日可用的信用额度**：[%s(USD)](%s)\n\n**昨日可用的信用额度**：%s(USD)\n\n**昨日消耗信用额度**：%s(USD)\n\n**预估剩余可用天数**：**%s天**" % (self.today_date, today_credits_num, asm_link, yes_credits_num, yes_run_num, now_yue_days)
+            push_text = "### %s-七麦科技-ASM信用额度提醒 \n\n**今日可用的信用额度**：[%s(USD)](%s)\n\n**昨日可用的信用额度**：%s(USD)\n\n**昨日消耗信用额度**：%s(USD)\n\n**预估剩余可用天数**：**%s天**" % (self.today_date, round(today_credits_num, 2), asm_link, round(yes_credits_num, 2), yes_run_num, now_yue_days)
             push_text_list.append([push_title, push_text])
             # 完毕后读取当前数据进行去重，
             df_new.drop_duplicates(['账单ID', '日期', '消耗总额'], keep='last', inplace=True)
